#!/bin/csh -f

# shell program to test xml2arff.pl 

# sub test 1: usual usage test
echo "Sub test 1: "

# test files 
set TESTFILE_1   = "test-1.train.xml"
set TESTFILE_2   = "test-1.test.xml"

# target files 
set TARGETFILE_1 = "test-1.train.reqd"   
set TARGETFILE_2 = "test-1.test.reqd" 

# regex file
set REGEXFILE    = "test-1.regex"

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE_1)) then
    echo "File $TESTFILE_1 does not exist... aborting"
    exit
endif

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE_2)) then
    echo "File $TESTFILE_2 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_1)) then
    echo "File $TARGETFILE_1 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_2)) then
    echo "File $TARGETFILE_2 does not exist... aborting"
    exit
endif

if (!(-e $REGEXFILE)) then
    echo "File $REGEXFILE does not exist... aborting"
    exit
endif

# the test 
echo "Testing xml2arff.pl thusly: xml2arff.pl --training $TESTFILE_1 --test $TESTFILE_2 $REGEXFILE"
xml2arff.pl --training $TESTFILE_1 --test $TESTFILE_2 $REGEXFILE

# find diffs
diff $TESTFILE_1.arff $TARGETFILE_1 > difference

if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_1) ... ok"
else
    echo "Following differences exist between $TESTFILE_1.arff and $TARGETFILE_1 :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TESTFILE_1.arff

# find diffs
diff $TESTFILE_2.arff $TARGETFILE_2 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_2) ... ok"
else
    echo "Following differences exist between $TESTFILE_2.arff and $TARGETFILE_2 :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TESTFILE_2.arff


# sub test 2: single source check

echo "Sub test 2:"
echo "Testing xml2arff.pl thusly: xml2arff.pl $REGEXFILE $TESTFILE_1"
xml2arff.pl $REGEXFILE $TESTFILE_1
diff $TESTFILE_1.arff $TARGETFILE_1 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_1) ... ok"
else
    echo "   Following differences exist between error and $TARGETFILE_1 : "
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TESTFILE_1.arff

# sub test 3: no source error check

echo "Sub test 3:"

set TARGETFILE_1 = "test-1.error-1"

echo "Testing xml2arff.pl thusly: xml2arff.pl $REGEXFILE >& error"
xml2arff.pl $REGEXFILE >& error
diff error $TARGETFILE_1 > difference 
if (-z difference) then
    echo "   Error message matches $TARGETFILE_1 ... ok"
else
    echo "   Following differences exist between error and $TARGETFILE_1 : "
    cat difference
endif
/bin/rm -f difference
/bin/rm -f error

# sub test 4: check for missing attrib names

echo "Sub test 4: "

set REGEXFILE  = "test-1.regex-1"
set TARGETFILE = "test-1.train.reqd-1"
set TESTFILE   = "test-1.train.xml"

echo "Testing xml2arff.pl thusly: xml2arff.pl $REGEXFILE $TESTFILE"
xml2arff.pl $REGEXFILE $TESTFILE
diff $TESTFILE.arff $TARGETFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE) ... ok"
else 
    echo "   Following differences exist between $TESTFILE.arff and $TARGETFILE : "
    cat difference
endif 
/bin/rm -f difference
/bin/rm -f $TESTFILE.arff

# sub test 5: test --relation

echo "Sub test 5: "

set TESTFILE   = "test-1.train.xml"
set REGEXFILE  = "test-1.regex"
set TARGETFILE = "test-1.train.reqd-2"

echo "Testing xml2arff.pl thusly: xml2arff.pl --relation word $REGEXFILE $TESTFILE"
xml2arff.pl --relation word $REGEXFILE $TESTFILE
diff $TESTFILE.arff $TARGETFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE) ... ok"
else
    echo "   Following differences exist between $TESTFILE.arff and $TARGETFILE : "
    cat difference
endif 
/bin/rm -f difference
/bin/rm -f $TESTFILE.arff


# sub test 6: test with multiple answers and multiple instances

echo "Sub test 6: "

set TESTFILE   = "test-1.train-1.xml"
set REGEXFILE  = "test-1.regex-2"
set TARGETFILE = "test-1.train-1.reqd"

echo "Testing xml2arff.pl thusly: xml2arff.pl $REGEXFILE $TESTFILE"
xml2arff.pl $REGEXFILE $TESTFILE
diff $TESTFILE.arff $TARGETFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE) ... ok" 
else 
    echo "   Following differences exist between $TESTFILE.arff and $TARGETFILE : "
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TESTFILE.arff


# sub test 7: test with tricky regex's

echo "Sub test 7: "

set TESTFILE = "test-1.train-2.xml"
set REGEXFILE = "test-1.train-2.regex"
set TARGETFILE = "test-1.train-2.reqd"

echo "Testing xml2arff.pl thusly: xml2arff.pl $REGEXFILE $TESTFILE"
xml2arff.pl $REGEXFILE $TESTFILE
diff $TESTFILE.arff $TARGETFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE) ... ok" 
else 
    echo "   Following differences exist between $TESTFILE.arff and $TARGETFILE : "
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TESTFILE.arff
